@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from cmsplugin_text_wrapper.models import Text
+from cmsplugin_text_wrapper.models import TextWrapper
 from django import forms
 from django.forms.models import ModelForm
 
@@ -8,6 +8,6 @@ class TextForm(ModelForm):
     body = forms.CharField()
 
     class Meta:
-        model = Text
+        model = TextWrapper
         fields = ('wrapper', 'body')
         exclude = ('page', 'position', 'placeholder', 'language', 'plugin_type')
